@@ -1,5 +1,5 @@
 /* GIO - GLib Input, Output and Streaming Library
- * 
+ *
  * Copyright (C) 2006-2007 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
@@ -37,13 +37,13 @@ static gboolean interactive = FALSE;
 static gboolean backup = FALSE;
 static gboolean no_target_directory = FALSE;
 
-static GOptionEntry entries[] = 
+static GOptionEntry entries[] =
 {
-	{ "no-target-directory", 'T', 0, G_OPTION_ARG_NONE, &no_target_directory, "no target directory", NULL },
-	{ "progress", 'p', 0, G_OPTION_ARG_NONE, &progress, "show progress", NULL },
-	{ "interactive", 'i', 0, G_OPTION_ARG_NONE, &interactive, "prompt before overwrite", NULL },
-	{ "backup", 'b', 0, G_OPTION_ARG_NONE, &backup, "backup existing destination files", NULL },
-	{ NULL }
+  { "no-target-directory", 'T', 0, G_OPTION_ARG_NONE, &no_target_directory, N_("no target directory"), NULL },
+  { "progress", 'p', 0, G_OPTION_ARG_NONE, &progress, N_("show progress"), NULL },
+  { "interactive", 'i', 0, G_OPTION_ARG_NONE, &interactive, N_("prompt before overwrite"), NULL },
+  { "backup", 'b', 0, G_OPTION_ARG_NONE, &backup, N_("backup existing destination files"), NULL },
+  { NULL }
 };
 
 static gboolean
@@ -51,7 +51,7 @@ is_dir (GFile *file)
 {
   GFileInfo *info;
   gboolean res;
-  
+
   info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_TYPE, 0, NULL, NULL);
   res = info && g_file_info_get_file_type (info) == G_FILE_TYPE_DIRECTORY;
   if (info)
@@ -64,10 +64,24 @@ show_progress (goffset current_num_bytes,
 	       goffset total_num_bytes,
 	       gpointer user_data)
 {
-  g_print ("progress %"G_GINT64_FORMAT"/%"G_GINT64_FORMAT"\n",
+  g_print (_("progress"));
+  g_print (" %"G_GINT64_FORMAT"/%"G_GINT64_FORMAT"\n",
 	   current_num_bytes, total_num_bytes);
 }
 
+static void
+show_help (GOptionContext *context, const char *error)
+{
+  char *help;
+
+  if (error)
+    g_printerr (_("Error: %s"), error);
+
+  help = g_option_context_get_help (context, TRUE, NULL);
+  g_printerr ("%s", help);
+  g_free (help);
+  g_option_context_free (context);
+}
 
 int
 main (int argc, char *argv[])
@@ -79,23 +93,22 @@ main (int argc, char *argv[])
   char *basename;
   int i;
   GFileCopyFlags flags;
-  
+
   setlocale (LC_ALL, "");
 
   g_type_init ();
-  
+
   error = NULL;
-  context = g_option_context_new ("- output files at <location>");
+  context = g_option_context_new (_("SOURCE... DEST - move file(s) from SOURCE to DEST"));
   g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
   g_option_context_parse (context, &argc, &argv, &error);
-  g_option_context_free (context);
-  
+
   if (error != NULL)
     {
-      g_printerr ("Error parsing commandline options: %s\n", error->message);
+      g_printerr (_("Error parsing commandline options: %s\n"), error->message);
       g_printerr ("\n");
       g_printerr (_("Try \"%s --help\" for more information."),
-                  g_get_prgname ());
+		  g_get_prgname ());
       g_printerr ("\n");
       g_error_free(error);
       return 1;
@@ -103,7 +116,7 @@ main (int argc, char *argv[])
 
   if (argc <= 2)
     {
-      g_printerr ("Missing operand\n");
+      show_help (context, _("Missing operand\n"));
       return 1;
     }
 
@@ -111,20 +124,23 @@ main (int argc, char *argv[])
 
   if (no_target_directory && argc > 3)
     {
-      g_printerr ("Too many arguments\n");
+      show_help (context, _("Too many arguments\n"));
       g_object_unref (dest);
       return 1;
     }
-  
+
   dest_is_dir = is_dir (dest);
 
   if (!dest_is_dir && argc > 3)
     {
-      g_printerr ("Target %s is not a directory\n", argv[argc-1]);
+      g_printerr (_("Target %s is not a directory\n"), argv[argc-1]);
+      show_help (context, NULL);
       g_object_unref (dest);
       return 1;
     }
 
+  g_option_context_free (context);
+
   for (i = 1; i < argc - 1; i++)
     {
       source = g_file_new_for_commandline_arg (argv[i]);
@@ -143,14 +159,14 @@ main (int argc, char *argv[])
 	flags |= G_FILE_COPY_BACKUP;
       if (!interactive)
 	flags |= G_FILE_COPY_OVERWRITE;
-	
+
       error = NULL;
       if (!g_file_move (source, target, flags, NULL, progress?show_progress:NULL, NULL, &error))
 	{
 	  if (interactive && g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
 	    {
 	      char line[16];
-	      
+
 	      g_error_free (error);
 	      error = NULL;
 
@@ -169,7 +185,7 @@ main (int argc, char *argv[])
 	  else
 	    {
 	    move_failed:
-	      g_printerr ("Error moving file %s: %s\n", argv[i], error->message);
+	      g_printerr (_("Error moving file %s: %s\n"), argv[i], error->message);
 	      g_error_free (error);
 	    }
 	}
